@@ -781,7 +781,7 @@ our %notfound = (
     'ccwhois.verisign-grs.com'   => '^No match for',
     'jobswhois.verisign-grs.com' => '^No match for',
     'tvwhois.verisign-grs.com'   => '^No match for',
-    'whois.registrypro.pro'      => '^No match',
+    'whois.registrypro.pro'      => '^NOT FOUND',
     'whois.worldsite.ws'         => 'No match for',
     'whois.nic.travel'           => 'Not found: \S+',
     'whois.donuts.co'            => 'Domain not found',
@@ -876,7 +876,7 @@ our %notfound = (
     'whois.nic.sb'            => 'Status: Not Registered',
     'whois.iis.se'            => '^\S+ not found',
     'whois.nic.net.sg'        => '^Domain Not Found',
-    'whois.nic.sh'            => '^Domain \S+ - Available',
+    'whois.nic.sh'            => '^Domain \S+ is available',
     'whois.arnes.si'          => 'No entries found',
     'whois.nic.st'            => '^No entries found',
     'whois.adamsnames.tc'     => '^\S+ is not registered',
@@ -2532,6 +2532,8 @@ our %query_prefix = (
     'whois.pir.org.ns'         => 'HO ',
     'whois.biz.ns'             => 'nameserver ',
     'whois.nsiregistry.net.ns' => 'nameserver = ',
+
+    'whois.arin.net'           => 'n + ',
 );
 
 1;
